/* n-aria.js by nanto_vi
 *
 * WAI-ARIAのロール、ステート、プロパティの設定を補助する。
 *
 * 使い方:
 *
 *   NAria.setRole(element, "button")
 *     elementにbuttonロールを指定。
 *     同時にbuttonクラスが追加される。
 *
 *   NAria.setAttr(element, "tabindex", 0)
 *     elementにtabindex属性を指定。
 *     同時にfocusableクラスが追加される。
 *     値が0以上なら同時にnavigableクラスも追加される。
 *
 *   NAria.setAttr(element, "checked", true)
 *     elementのcheckedステートをtrueに設定。
 *     同時にcheckedクラスが追加される。
 *
 *   NAria.setAttr(element, "checked", false)
 *     elementのcheckedステートをfalseに設定。
 *     同時にcheckedクラスが(存在すれば)削除される。
 *
 *   NAria.setAttr(element, "checked", "mixed")
 *     elementのcheckedステートをmixedに設定。
 *     同時にchecked-mixedクラスが追加される。
 */

NAria = {
  setRole: function (element, role) {
    element.setAttribute("role", role);
    NClassAttr.add(element, role);
  },

  setAttr: function (element, name, value) {
    if (name == "tabindex") {
      element.tabIndex = value;
      NClassAttr.add(element, "focusable");
      if (value >= 0)
        NClassAttr.add(element, "navigable");
      else
        NClassAttr.remove(element, "navigable");
      return;
    }
    var oldValue = element.getAttribute("aria-" + name);
    if (oldValue) {
      NClassAttr.remove(element, name);
      NClassAttr.remove(element, name + "-" + oldValue);
    }
    element.setAttribute("aria-" + name, value);
    if (value)
      NClassAttr.add(element, (value === true) ? name : name + "-" + value);
  }
};
