function RadioGroup(group, valueHolder) {
  this.group = group;
  this.valueHolder = valueHolder;
  this.radios = [];
  this.currentRadio = null;
  var elements = this.group.getElementsByTagName("*");
  for (var i = 0, n = elements.length; i < n; i++) {
    var radio = elements[i];
    if (radio.getAttribute("role") != "radio") continue;
    radio.radioPosition = this.radios.length;
    if (radio.getAttribute("aria-checked") == "true")
      this.currentRadio = radio;
    else
      radio.tabIndex = -1;
    this.radios.push(radio);
  }
  if (!this.currentRadio) {
    this.currentRadio = this.radios[0];
    this.currentRadio.tabIndex = 0;
  }
  new NEvent(this.group, "click", this.onActivate, this);
  new NEvent(this.group, "ne_keydown", this.onKeyDown, this);
}

RadioGroup.prototype.select = function (radio) {
  if (radio == this.currentRadio) return;
  this.setRadioState(this.currentRadio, false);
  this.setRadioState(radio, true);
  this.currentRadio = radio;
  this.valueHolder.value = radio.textContent || radio.innerText || "";
  if (radio.focus) radio.focus();
};

RadioGroup.prototype.setRadioState = function (radio, checked) {
  NAria.setAttr(radio, "checked", checked);
  NAria.setAttr(radio, "tabindex", checked ? 0 : -1);
  if (checked)
    NAria.setAttr(this.group, "activedescendant", radio.id);
};

RadioGroup.prototype.changeRadioBy = function (offset) {
  var position = this.currentRadio.radioPosition;
  position = (position + offset) % this.radios.length;
  if (position < 0) position += this.radios.length;
  this.select(this.radios[position]);
};

RadioGroup.prototype.onActivate = function (event) {
  var radio = event.target;
  if (radio.getAttribute("role") != "radio") return;
  this.select(radio);
  event.preventDefault();
};

RadioGroup.prototype.onKeyDown = function (event) {
  var radio = event.target;
  if (radio.getAttribute("role") != "radio" ||
      event.altKey || event.ctrlKey || event.shiftKey || event.metaKey)
    return;
  var DOM_VK_RETURN = 13, DOM_VK_SPACE = 32,
      DOM_VK_LEFT   = 37, DOM_VK_UP    = 38,
      DOM_VK_RIGHT  = 39, DOM_VK_DOWN  = 40;
  switch (event.keyCode) {
  case DOM_VK_RETURN:
  case DOM_VK_SPACE:
    this.select(radio);
    break;

  case DOM_VK_LEFT:
  case DOM_VK_UP:
    this.changeRadioBy(-1);
    break;

  case DOM_VK_RIGHT:
  case DOM_VK_DOWN:
    this.changeRadioBy(1);
    break;

  default:
    return;
  }
  event.preventDefault();
};
