function Tabbox(container) {
  this.container = container;
  this.tabs = [];
  this.panels = [];
  for (var node = this.container.firstChild; node; node = node.nextSibling) {
    var nodeName = node.nodeName.toLowerCase();
    if (nodeName == "dt")
      this.tabs.push(node);
    else if (nodeName == "dd")
      this.panels.push(node);
  }
  this.currentTab = this.tabs[0];
  NAria.setRole(this.container, "tablist");
  for (var i = 0; i < this.tabs.length; i++) {
    this.tabs[i].tabPosition = i;
    NAria.setRole(this.tabs[i], "tab");
    NAria.setRole(this.panels[i], "tabpanel");
    NAria.setAttr(this.panels[i], "labelledby", this.tabs[i].id);
    this.setTabState(this.tabs[i], i == 0);
  }
  new NEvent(this.container, "click", this.onActivate, this);
  new NEvent(this.container, "ne_keydown", this.onKeyDown, this);
}

Tabbox.prototype.setTabState = function (tab, selected) {
  NAria.setAttr(tab, "tabindex", selected ? 0 : -1);
  NAria.setAttr(this.panels[tab.tabPosition], "hidden", !selected);
  if (selected)
    NAria.setAttr(this.container, "activedescendant", tab.id);
};

Tabbox.prototype.selectTab = function (tab) {
  if (tab == this.currentTab) return;
  this.setTabState(this.currentTab, false);
  this.setTabState(tab, true);
  this.currentTab = tab;
  if (tab.focus) tab.focus();
};

Tabbox.prototype.changeTabBy = function (offset) {
  var position = this.currentTab.tabPosition;
  position = (position + offset) % this.tabs.length;
  if (position < 0) position += this.tabs.length;
  this.selectTab(this.tabs[position]);
};

Tabbox.prototype.onActivate = function (event) {
  var tab = event.target;
  if (tab.getAttribute("role") != "tab") return;
  this.selectTab(tab);
};

Tabbox.prototype.onKeyDown = function (event) {
  var tab = event.target;
  if (tab.getAttribute("role") != "tab" ||
      event.altKey || event.ctrlKey || event.shiftKey || event.metaKey)
    return;
  var DOM_VK_RETURN = 13, DOM_VK_LEFT = 37, DOM_VK_RIGHT = 39;
  switch (event.keyCode) {
  case DOM_VK_RETURN: this.selectTab(tab);  break;
  case DOM_VK_LEFT:   this.changeTabBy(-1); break;
  case DOM_VK_RIGHT:  this.changeTabBy(1);  break;
  default: return;
  }
  event.preventDefault();
};
